summaryrefslogtreecommitdiffstats
path: root/tests/auto/unit/qmediaplayerwidgets
diff options
context:
space:
mode:
authorJason McDonald <jason.mcdonald@nokia.com>2011-12-02 14:39:42 +1000
committerQt by Nokia <qt-info@nokia.com>2011-12-05 02:32:37 +0100
commit3171081d43d6f83036807e3ad663d6918eb8e55c (patch)
treebf4639ff624262abf34afed699cdd016c3abbb37 /tests/auto/unit/qmediaplayerwidgets
parent4c834365c69dfcb6340a59321f483c8d20296806 (diff)
Cleanup multimedia unit tests.
Use QTEST_MAIN or QTEST_GUILESS_MAIN instead of equivalent custom main() functions. Also collapse each test into a single source file, in line with most other autotests. Change-Id: I38c7b6a9eb0ff1c9b8ac44de7d5f40d6ac6c46ea Reviewed-by: Michael Goddard <michael.goddard@nokia.com>
Diffstat (limited to 'tests/auto/unit/qmediaplayerwidgets')
-rwxr-xr-xtests/auto/unit/qmediaplayerwidgets/main.cpp53
-rw-r--r--tests/auto/unit/qmediaplayerwidgets/qmediaplayerwidgets.pro8
-rw-r--r--tests/auto/unit/qmediaplayerwidgets/tst_qmediaplayerwidgets.cpp39
-rwxr-xr-xtests/auto/unit/qmediaplayerwidgets/tst_qmediaplayerwidgets.h79
4 files changed, 38 insertions, 141 deletions
diff --git a/tests/auto/unit/qmediaplayerwidgets/main.cpp b/tests/auto/unit/qmediaplayerwidgets/main.cpp
deleted file mode 100755
index e7614c975..000000000
--- a/tests/auto/unit/qmediaplayerwidgets/main.cpp
+++ /dev/null
@@ -1,53 +0,0 @@
-/****************************************************************************
-**
-** Copyright (C) 2010 Nokia Corporation and/or its subsidiary(-ies).
-** All rights reserved.
-** Contact: Nokia Corporation (qt-info@nokia.com)
-**
-** This file is part of the Qt Toolkit.
-**
-** $QT_BEGIN_LICENSE:LGPL$
-** GNU Lesser General Public License Usage
-** This file may be used under the terms of the GNU Lesser General Public
-** License version 2.1 as published by the Free Software Foundation and
-** appearing in the file LICENSE.LGPL included in the packaging of this
-** file. Please review the following information to ensure the GNU Lesser
-** General Public License version 2.1 requirements will be met:
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
-**
-** In addition, as a special exception, Nokia gives you certain additional
-** rights. These rights are described in the Nokia Qt LGPL Exception
-** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU General
-** Public License version 3.0 as published by the Free Software Foundation
-** and appearing in the file LICENSE.GPL included in the packaging of this
-** file. Please review the following information to ensure the GNU General
-** Public License version 3.0 requirements will be met:
-** http://www.gnu.org/copyleft/gpl.html.
-**
-** Other Usage
-** Alternatively, this file may be used in accordance with the terms and
-** conditions contained in a signed written agreement between you and Nokia.
-**
-**
-**
-**
-**
-** $QT_END_LICENSE$
-**
-****************************************************************************/
-#include <QtWidgets/QApplication>
-#include <QtTest/QtTest>
-
-#include "tst_qmediaplayerwidgets.h"
-
-int main(int argc, char**argv)
-{
- QApplication app(argc,argv);
- int ret;
- tst_QMediaPlayerWidgets test_api;
- ret = QTest::qExec(&test_api, argc, argv);
- return ret;
-}
diff --git a/tests/auto/unit/qmediaplayerwidgets/qmediaplayerwidgets.pro b/tests/auto/unit/qmediaplayerwidgets/qmediaplayerwidgets.pro
index c5c602938..97232f934 100644
--- a/tests/auto/unit/qmediaplayerwidgets/qmediaplayerwidgets.pro
+++ b/tests/auto/unit/qmediaplayerwidgets/qmediaplayerwidgets.pro
@@ -1,11 +1,7 @@
-CONFIG += testcase
+CONFIG += testcase no_private_qt_headers_warning
TARGET = tst_qmediaplayerwidgets
-
QT += network multimedia-private multimediawidgets-private testlib widgets
-CONFIG += no_private_qt_headers_warning
-
-HEADERS += tst_qmediaplayerwidgets.h
-SOURCES += main.cpp tst_qmediaplayerwidgets.cpp
+SOURCES += tst_qmediaplayerwidgets.cpp
include (../qmultimedia_common/mock.pri)
include (../qmultimedia_common/mockplayer.pri)
diff --git a/tests/auto/unit/qmediaplayerwidgets/tst_qmediaplayerwidgets.h b/tests/auto/unit/qmediaplayerwidgets/tst_qmediaplayerwidgets.h
deleted file mode 100755
index e5f9b674a..000000000
--- a/tests/auto/unit/qmediaplayerwidgets/tst_qmediaplayerwidgets.h
+++ /dev/null
@@ -1,79 +0,0 @@
-/****************************************************************************
-**
-** Copyright (C) 2010 Nokia Corporation and/or its subsidiary(-ies).
-** All rights reserved.
-** Contact: Nokia Corporation (qt-info@nokia.com)
-**
-** This file is part of the Qt Toolkit.
-**
-** $QT_BEGIN_LICENSE:LGPL$
-** GNU Lesser General Public License Usage
-** This file may be used under the terms of the GNU Lesser General Public
-** License version 2.1 as published by the Free Software Foundation and
-** appearing in the file LICENSE.LGPL included in the packaging of this
-** file. Please review the following information to ensure the GNU Lesser
-** General Public License version 2.1 requirements will be met:
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
-**
-** In addition, as a special exception, Nokia gives you certain additional
-** rights. These rights are described in the Nokia Qt LGPL Exception
-** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU General
-** Public License version 3.0 as published by the Free Software Foundation
-** and appearing in the file LICENSE.GPL included in the packaging of this
-** file. Please review the following information to ensure the GNU General
-** Public License version 3.0 requirements will be met:
-** http://www.gnu.org/copyleft/gpl.html.
-**
-** Other Usage
-** Alternatively, this file may be used in accordance with the terms and
-** conditions contained in a signed written agreement between you and Nokia.
-**
-**
-**
-**
-**
-** $QT_END_LICENSE$
-**
-****************************************************************************/
-#ifndef TST_QMEDIAPLAYER_H
-#define TST_QMEDIAPLAYER_H
-
-#include <QtTest/QtTest>
-#include <QtCore/qdebug.h>
-#include <QtCore/qbuffer.h>
-#include <QtNetwork/qnetworkconfiguration.h>
-
-#include <qabstractvideosurface.h>
-#include <qmediaplayer.h>
-#include <qmediaplayercontrol.h>
-
-#include "mockmediaserviceprovider.h"
-#include "mockmediaplayerservice.h"
-
-QT_USE_NAMESPACE
-
-class tst_QMediaPlayerWidgets: public QObject
-{
- Q_OBJECT
-
-public slots:
- void initTestCase();
- void cleanupTestCase();
- void init();
- void cleanup();
-
-private slots:
- void testSetVideoOutput();
- void testSetVideoOutputNoService();
- void testSetVideoOutputNoControl();
-
-private:
- MockMediaServiceProvider *mockProvider;
- MockMediaPlayerService *mockService;
- QMediaPlayer *player;
-};
-
-#endif //TST_QMEDIAPLAYER_H
diff --git a/tests/auto/unit/qmediaplayerwidgets/tst_qmediaplayerwidgets.cpp b/tests/auto/unit/qmediaplayerwidgets/tst_qmediaplayerwidgets.cpp
index ac9ffa0ce..a8c6b325a 100644
--- a/tests/auto/unit/qmediaplayerwidgets/tst_qmediaplayerwidgets.cpp
+++ b/tests/auto/unit/qmediaplayerwidgets/tst_qmediaplayerwidgets.cpp
@@ -4,7 +4,7 @@
** All rights reserved.
** Contact: Nokia Corporation (qt-info@nokia.com)
**
** This file is part of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** GNU Lesser General Public License Usage
@@ -41,12 +41,43 @@
//TESTED_COMPONENT=src/multimedia
-#include "tst_qmediaplayerwidgets.h"
-#include "mockvideosurface.h"
+#include <QtTest/QtTest>
+#include <QtCore/qdebug.h>
+#include <QtCore/qbuffer.h>
+#include <QtNetwork/qnetworkconfiguration.h>
+
#include <qgraphicsvideoitem.h>
+#include <qabstractvideosurface.h>
+#include <qmediaplayer.h>
+#include <qmediaplayercontrol.h>
+
+#include "mockmediaserviceprovider.h"
+#include "mockmediaplayerservice.h"
+#include "mockvideosurface.h"
QT_USE_NAMESPACE
+class tst_QMediaPlayerWidgets: public QObject
+{
+ Q_OBJECT
+
+public slots:
+ void initTestCase();
+ void cleanupTestCase();
+ void init();
+ void cleanup();
+
+private slots:
+ void testSetVideoOutput();
+ void testSetVideoOutputNoService();
+ void testSetVideoOutputNoControl();
+
+private:
+ MockMediaServiceProvider *mockProvider;
+ MockMediaPlayerService *mockService;
+ QMediaPlayer *player;
+};
+
void tst_QMediaPlayerWidgets::initTestCase()
{
qRegisterMetaType<QMediaPlayer::State>("QMediaPlayer::State");
@@ -160,3 +191,5 @@ void tst_QMediaPlayerWidgets::testSetVideoOutputNoControl()
QVERIFY(service.rendererControl->surface() == 0);
}
+QTEST_MAIN(tst_QMediaPlayerWidgets)
+#include "tst_qmediaplayerwidgets.moc"
@@ -4,7 +4,7 @@
** Contact: Nokia Corporation (qt-info@nokia.com)
**
-** This file is part of the Qt Toolkit.
+** This file is part of the test suite of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$